RESTful — Glances 3.1.3 documentation

# RESTful

You can export statistics to a `RESTful` JSON server. All the available stats will be exported in one big (~15 KB) POST request to the RESTful endpoint.

The RESTful endpoint should be defined in the Glances configuration file as following:

    [restful]
    # Configuration for the --export-restful option
    # Example, export to http://localhost:6789/
    host=localhost
    port=6789
    protocol=http
    path=/

URL Syntax:

    http://localhost:6789/
    |      |         |   |
    |      |         |   path
    |      |         port
    |      host
    protocol

and run Glances with:

    $ glances --export restful

Glances will generate stats as a big JSON dictionary (see example here).